==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Oorsprong</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Groote oorsprong assen tonen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Linialen en scrollbars</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Linialen tonen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Scrollbars tonen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Muiscursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Dradenkruis tonen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Groot dradenkruis tonen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Auto zoom</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Rand (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Auto zoom na het laden</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Kleuraanpassing</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Voorkom wit op wit / zwart op zwart weergave</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Color lightness threshold:</source>
        <translation>Kleur lichtheid drempel:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Linetypes</source>
        <translation>Lijntypen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automatisch scherm gebaseerde lijntypen gebruiken in model weergave</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Schaal lijntype patronen gebaseerd op lijndikte</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Patroon schaal voor lijndikte 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Weergave en prestatie</translation>
    </message>
    <message>
        <location line="+146"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Objecten met meer dan N streepjes als doorlopend weergeven:</translation>
    </message>
    <message>
        <location line="+186"/>
        <source>Use full resolution for Retina display</source>
        <translation>Gebruik volledige resolutie voor Retina-display</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Anti-aliasing altijd aan</translation>
    </message>
    <message>
        <location line="-411"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automatisch scherm gebaseerde lijntypen gebruiken in model weergave</translation>
    </message>
    <message>
        <location line="+78"/>
        <source>Number of preview entities:</source>
        <translation>Aantal voorbeeld objecten:</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Text height display threshold (px):</source>
        <translation>Drempel voor weergave van tekst (px):</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Weergave van bogen als lijnen onder deze hoek (graden):</translation>
    </message>
    <message>
        <location line="+111"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Minimale hoek voor weergave van bogens (graden):</translation>
    </message>
    <message>
        <location line="+82"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Time-out voor weergave van arcering:</translation>
    </message>
    <message>
        <location line="+76"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Maximum aantal weergeven referentiepunten:</translation>
    </message>
    <message>
        <location line="+70"/>
        <source>Selection</source>
        <translation>Selectie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Blijvende selectie</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafische weergave</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Weergave</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ts/GraphicsViewPreferences_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl_NL">
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Origin</source>
        <translation>Oorsprong</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show large origin axis</source>
        <translation>Groote oorsprong assen tonen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Rulers and Scrollbars</source>
        <translation>Linialen en scrollbars</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show rulers</source>
        <translation>Linialen tonen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show scrollbars</source>
        <translation>Scrollbars tonen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Cursor</source>
        <translation>Muiscursor</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Show crosshairs</source>
        <translation>Dradenkruis tonen</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Show large crosshairs</source>
        <translation>Groot dradenkruis tonen</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Auto Zoom</source>
        <translation>Auto zoom</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Margin (px):</source>
        <translation>Rand (px):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Auto zoom on load</source>
        <translation>Auto zoom na het laden</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Color Adjustment</source>
        <translation>Kleuraanpassing</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Prevent white on white / black on black display</source>
        <translation>Voorkom wit op wit / zwart op zwart weergave</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Color lightness threshold:</source>
        <translation>Kleur lichtheid drempel:</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Disable for printing</source>
        <translation>Uitschakelen voor afdrukken</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Linetypes</source>
        <translation>Lijntypen</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Auto switch to screen based linetypes in model view</source>
        <translation>Automatisch scherm gebaseerde lijntypen gebruiken in model weergave</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale linetype patterns by line weight</source>
        <translation>Schaal lijntype patronen gebaseerd op lijndikte</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>Pattern scale for lineweight 0.00mm:</source>
        <translation>Patroon schaal voor lijndikte 0.00mm:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Display and Performance</source>
        <translation>Weergave en prestatie</translation>
    </message>
    <message>
        <location line="+229"/>
        <source>Display entities with more than N dashes as continuous:</source>
        <translation>Objecten met meer dan N streepjes als doorlopend weergeven:</translation>
    </message>
    <message>
        <location line="-216"/>
        <source>Use full resolution for Retina display</source>
        <translation>Gebruik volledige resolutie voor Retina-display</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Anti-aliasing on by default</source>
        <translation>Anti-aliasing altijd aan</translation>
    </message>
    <message>
        <location line="-78"/>
        <source>Automatically use screen based linetypes in model view</source>
        <translation>Automatisch scherm gebaseerde lijntypen gebruiken in model weergave</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Number of preview entities:</source>
        <translation>Aantal voorbeeld objecten:</translation>
    </message>
    <message>
        <source>Text height display threshold (px):</source>
        <translation type="vanished">Drempel voor weergave van tekst (px):</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Display arcs as lines below this angle (degrees):</source>
        <translation>Weergave van bogen als lijnen onder deze hoek (graden):</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Minimum angle step for rendering arcs (degrees):</source>
        <translation>Minimale hoek voor weergave van bogens (graden):</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Timeout for hatch rendering:</source>
        <translation>Time-out voor weergave van arcering:</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Maximum number of reference points displayed:</source>
        <translation>Maximum aantal weergeven referentiepunten:</translation>
    </message>
    <message>
        <location line="+80"/>
        <source>Selection</source>
        <translation>Selectie</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Persistent Selection</source>
        <translation>Blijvende selectie</translation>
    </message>
</context>
<context>
    <name>GraphicsViewPreferences</name>
    <message>
        <location filename="../GraphicsViewPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Grafische weergave</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Appearance</source>
        <translation>Weergave</translation>
    </message>
</context>
</TS>
